pycalphad package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pycalphad.codegen
   pycalphad.core
   pycalphad.io
   pycalphad.mapping
   pycalphad.models
   pycalphad.plot
   pycalphad.property_framework

Submodules
----------

pycalphad.model module
----------------------

.. automodule:: pycalphad.model
   :members:
   :undoc-members:
   :show-inheritance:

pycalphad.variables module
--------------------------

.. automodule:: pycalphad.variables
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pycalphad
   :members:
   :undoc-members:
   :show-inheritance:
